/** @jsx createElement */
import { BaseItem, PluginSubscribeParams } from '@algolia/autocomplete-core';
import { AutocompletePlugin, AutocompleteSource, AutocompleteState } from '@algolia/autocomplete-js';
import { OnTagsChangeParams } from './createTags';
import type { DefaultTagType, BaseTag, Tag } from './types';
declare type OnChangeParams<TTag extends DefaultTagType = DefaultTagType> = PluginSubscribeParams<any> & OnTagsChangeParams<TTag>;
declare type GetTagParams<TItem extends BaseItem> = {
    item: TItem;
};
declare type TagsPluginData<TTag extends DefaultTagType = DefaultTagType> = {
    /**
     * Returns the current list of tags.
     *
     * @link https://www.algolia.com/doc/ui-libraries/autocomplete/api-reference/autocomplete-plugin-tags/createtagsplugin/#param-tags
     */
    tags: Array<Tag<TTag>>;
    /**
     * Adds tags to the list.
     *
     * @link https://www.algolia.com/doc/ui-libraries/autocomplete/api-reference/autocomplete-plugin-tags/createtagsplugin/#param-addtags
     */
    addTags: (tags: Array<BaseTag<TTag>>) => void;
    /**
     * Sets the list of tags.
     *
     * @link https://www.algolia.com/doc/ui-libraries/autocomplete/api-reference/autocomplete-plugin-tags/createtagsplugin/#param-settags
     */
    setTags: (tags: Array<BaseTag<TTag>>) => void;
};
export declare type TagsApi<TTag extends DefaultTagType = DefaultTagType> = TagsPluginData<TTag>;
export declare type CreateTagsPluginParams<TItem extends BaseItem, TTag extends DefaultTagType> = {
    /**
     * A set of initial tags to pass to the plugin.
     *
     * @link https://www.algolia.com/doc/ui-libraries/autocomplete/api-reference/autocomplete-plugin-tags/createtagsplugin/#param-initialtags
     */
    initialTags?: Array<BaseTag<TTag>>;
    /**
     * A function to specify what sources the plugin should subscribe to. The plugin adds a tag when selecting an item from these sources.
     *
     * @link https://www.algolia.com/doc/ui-libraries/autocomplete/api-reference/autocomplete-plugin-tags/createtagsplugin/#param-gettagssubscribers
     */
    getTagsSubscribers?(): Array<{
        sourceId: string;
        getTag(params: GetTagParams<TItem>): BaseTag<TTag>;
    }>;
    /**
     * A function to transform the returned tags source.
     *
     * @link https://www.algolia.com/doc/ui-libraries/autocomplete/api-reference/autocomplete-plugin-tags/createtagsplugin/#param-transformsource
     */
    transformSource?(params: {
        source: AutocompleteSource<Tag<TTag>>;
        state: AutocompleteState<Tag<TTag>>;
    }): AutocompleteSource<Tag<TTag>> | undefined;
    /**
     * A function called when the list of tags changes.
     *
     * @link https://www.algolia.com/doc/ui-libraries/autocomplete/api-reference/autocomplete-plugin-tags/createtagsplugin/#param-onchange
     */
    onChange?(params: OnChangeParams<TTag>): void;
};
export declare function createTagsPlugin<TItem extends BaseItem, TTag extends DefaultTagType = DefaultTagType>(options?: CreateTagsPluginParams<TItem, TTag>): AutocompletePlugin<Tag<TTag>, TagsPluginData<TTag>>;
export {};
