/*! @algolia/autocomplete-plugin-tags 1.19.2 | MIT License | © Algolia, Inc. and contributors | https://github.com/algolia/autocomplete */
(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
  typeof define === 'function' && define.amd ? define(['exports'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global["@algolia/autocomplete-plugin-tags"] = {}));
})(this, (function (exports) { 'use strict';

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);
    if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);
      enumerableOnly && (symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      })), keys.push.apply(keys, symbols);
    }
    return keys;
  }
  function _objectSpread2(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = null != arguments[i] ? arguments[i] : {};
      i % 2 ? ownKeys(Object(source), !0).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
    return target;
  }
  function _defineProperty(obj, key, value) {
    key = _toPropertyKey(key);
    if (key in obj) {
      Object.defineProperty(obj, key, {
        value: value,
        enumerable: true,
        configurable: true,
        writable: true
      });
    } else {
      obj[key] = value;
    }
    return obj;
  }
  function _toConsumableArray(arr) {
    return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread();
  }
  function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) return _arrayLikeToArray(arr);
  }
  function _iterableToArray(iter) {
    if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter);
  }
  function _unsupportedIterableToArray(o, minLen) {
    if (!o) return;
    if (typeof o === "string") return _arrayLikeToArray(o, minLen);
    var n = Object.prototype.toString.call(o).slice(8, -1);
    if (n === "Object" && o.constructor) n = o.constructor.name;
    if (n === "Map" || n === "Set") return Array.from(o);
    if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
  }
  function _arrayLikeToArray(arr, len) {
    if (len == null || len > arr.length) len = arr.length;
    for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];
    return arr2;
  }
  function _nonIterableSpread() {
    throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }
  function _toPrimitive(input, hint) {
    if (typeof input !== "object" || input === null) return input;
    var prim = input[Symbol.toPrimitive];
    if (prim !== undefined) {
      var res = prim.call(input, hint || "default");
      if (typeof res !== "object") return res;
      throw new TypeError("@@toPrimitive must return a primitive value.");
    }
    return (hint === "string" ? String : Number)(input);
  }
  function _toPropertyKey(arg) {
    var key = _toPrimitive(arg, "string");
    return typeof key === "symbol" ? key : String(key);
  }

  function createRef(initialValue) {
    return {
      current: initialValue
    };
  }

  var noop = function noop() {};

  function createTags(_ref) {
    var _ref$initialTags = _ref.initialTags,
      initialTags = _ref$initialTags === void 0 ? [] : _ref$initialTags;
    var tagsRef = createRef(mapToTags(initialTags));
    var onChangeListeners = [];
    function mapToTags(baseTags) {
      return baseTags.map(function (baseTag) {
        var tag = _objectSpread2(_objectSpread2({}, baseTag), {}, {
          remove: function remove() {
            var prevTags = tagsRef.current.slice();
            tagsRef.current = tagsRef.current.filter(function (tagRef) {
              return tag !== tagRef;
            });
            onChangeListeners.forEach(function (listener) {
              return listener({
                prevTags: prevTags,
                tags: tagsRef.current
              });
            });
          }
        });
        return tag;
      });
    }
    return {
      get: function get() {
        return tagsRef.current;
      },
      set: function set(baseTags) {
        var prevTags = tagsRef.current.slice();
        tagsRef.current = mapToTags(baseTags);
        onChangeListeners.forEach(function (listener) {
          return listener({
            prevTags: prevTags,
            tags: tagsRef.current
          });
        });
      },
      add: function add(baseTags) {
        var _tagsRef$current;
        var prevTags = tagsRef.current.slice();
        (_tagsRef$current = tagsRef.current).push.apply(_tagsRef$current, _toConsumableArray(mapToTags(baseTags)));
        onChangeListeners.forEach(function (listener) {
          return listener({
            prevTags: prevTags,
            tags: tagsRef.current
          });
        });
      },
      onChange: function onChange(listener) {
        onChangeListeners.push(listener);
      }
    };
  }

  function createTagsPlugin() {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var _getOptions = getOptions(options),
      initialTags = _getOptions.initialTags,
      getTagsSubscribers = _getOptions.getTagsSubscribers,
      transformSource = _getOptions.transformSource,
      onChange = _getOptions.onChange;
    var tags = createTags({
      initialTags: initialTags
    });
    var tagsApi = {
      setTags: tags.set,
      addTags: tags.add
    };
    return {
      name: 'aa.tagsPlugin',
      subscribe: function subscribe(params) {
        var setContext = params.setContext,
          onSelect = params.onSelect,
          setIsOpen = params.setIsOpen,
          refresh = params.refresh;
        var subscribers = getTagsSubscribers();
        setContext({
          tagsPlugin: _objectSpread2(_objectSpread2({}, tagsApi), {}, {
            tags: tags.get()
          })
        });
        onSelect(function (_ref) {
          var source = _ref.source,
            item = _ref.item;
          var subscriber = subscribers.find(function (_ref2) {
            var sourceId = _ref2.sourceId;
            return sourceId === source.sourceId;
          });
          if (subscriber) {
            tags.add([subscriber.getTag({
              item: item
            })]);
          }
        });
        tags.onChange(function (_ref3) {
          var prevTags = _ref3.prevTags;
          setContext({
            tagsPlugin: _objectSpread2(_objectSpread2({}, tagsApi), {}, {
              tags: tags.get()
            })
          });
          setIsOpen(true);
          onChange(_objectSpread2(_objectSpread2({}, params), {}, {
            prevTags: prevTags,
            tags: tags.get()
          }));
          refresh();
        });
      },
      getSources: function getSources(_ref4) {
        var state = _ref4.state;
        return [transformSource({
          source: {
            sourceId: 'tagsPlugin',
            getItems: function getItems() {
              return tags.get();
            },
            onSelect: function onSelect(_ref5) {
              var item = _ref5.item;
              item.remove();
            },
            templates: {
              item: function item(_ref6) {
                var item = _ref6.item,
                  createElement = _ref6.createElement;
                return createElement("div", {
                  className: "aa-TagsPlugin-Tag"
                }, createElement("span", {
                  className: "aa-TagsPlugin-TagLabel"
                }, item.label), createElement("button", {
                  type: "button",
                  className: "aa-TagsPlugin-RemoveButton",
                  title: "Remove this tag"
                }, createElement("svg", {
                  fill: "none",
                  stroke: "currentColor",
                  strokeLinecap: "round",
                  strokeLinejoin: "round",
                  strokeWidth: 2,
                  viewBox: "0 0 24 24"
                }, createElement("path", {
                  d: "M18 6L6 18"
                }), createElement("path", {
                  d: "M6 6L18 18"
                }))));
              }
            }
          },
          state: state
        })];
      },
      data: _objectSpread2(_objectSpread2({}, tagsApi), {}, {
        get tags() {
          return tags.get();
        }
      }),
      __autocomplete_pluginOptions: options
    };
  }
  function getOptions(options) {
    return _objectSpread2({
      initialTags: [],
      getTagsSubscribers: function getTagsSubscribers() {
        return [];
      },
      transformSource: function transformSource(_ref7) {
        var source = _ref7.source;
        return source;
      },
      onChange: noop
    }, options);
  }

  exports.createTagsPlugin = createTagsPlugin;

  Object.defineProperty(exports, '__esModule', { value: true });

}));
//# sourceMappingURL=index.development.js.map
